@@ -277,3 +277,44 @@ class Client(http.HTTPClient):
         """
         url = utils.generate_url('/policies', username)
         return self.delete(url, headers=self.headers, body=body).json()
+
+    @decorator.refresh_jwt_token
+    def create_scheduler(self, cloud_id, body):
+        """Create a scheduler belong to a cloud.
+
+        :param cloud_id: The id of cloud.
+        :param body: A dictionary object.
+        """
+        url = utils.generate_url('/schedulers', cloud_id)
+        return self.post(url, body=body, headers=self.headers).json()
+
+    @decorator.refresh_jwt_token
+    def list_schedulers(self, cloud_id, **kwargs):
+        """List all schedulers belong to a cloud.
+
+        :param cloud_id: The id of cloud.
+        :param tags: (optional) A list of tags to filter the scheduler list by.
+                     Scalers that match all tags in this list will be returned.
+        :param tags_any: (optional) A list of tags to filter the scheduler list by.
+                         Scalers that match any tags in this list will be returned.
+        """
+        url = utils.generate_url('/schedulers', cloud_id, **kwargs)
+        return self.get(url, headers=self.headers).json()
+
+    @decorator.refresh_jwt_token
+    def delete_scheduler(self, cloud_id, scheduler_id=None):
+        """Delete a scheduler."""
+        url = utils.generate_url('/schedulers', cloud_id, scheduler_id)
+        return self.delete(url, headers=self.headers).json()
+
+    @decorator.refresh_jwt_token
+    def update_scheduler(self, cloud_id, scheduler_id, body=None):
+        """Update a scheduler information.
+
+        :param cloud_id: The id of cloud.
+        :param scheduler_id: The id of scheduler.
+        :param body: (optional) A dictionary object. If it
+                     is None, the scheduler won't be updated.
+        """
+        url = utils.generate_url('/schedulers', cloud_id, scheduler_id)
+        return self.put(url, body=body, headers=self.headers).json()
